pub enum BatchCommitError {
EmptyBatch,
DuplicateKeyInBatch {
key: Vec<u8>,
},
IntentNotFound {
key: Vec<u8>,
},
TxnIdMismatch {
key: Vec<u8>,
},
StartTsMismatch {
key: Vec<u8>,
},
InvalidCommitTimestamp {
start_ts: Timestamp,
commit_ts: Timestamp,
},
CommitTsTooEarly {
key: Vec<u8>,
commit_ts: Timestamp,
min_commit_ts: Timestamp,
},
CommitTsTooOld {
key: Vec<u8>,
commit_ts: Timestamp,
latest_commit_ts: Timestamp,
},
Backend(String),
}Expand description
Error during a commit batch.
Variants
EmptyBatch
The batch contained no commit operations.
DuplicateKeyInBatch
The batch contains multiple commits for the same key.
IntentNotFound
The intent to be committed was not found.
TxnIdMismatch
The transaction ID on the intent does not match the commit request.
StartTsMismatch
The start timestamp on the intent does not match the commit request.
InvalidCommitTimestamp
The commit timestamp is less than or equal to the start timestamp.
Fields
CommitTsTooEarly
The commit timestamp is earlier than the intent’s required minimum commit timestamp.
Fields
CommitTsTooOld
The commit timestamp is older than the latest committed version for a key.
Fields
Backend(String)
An error returned by the backend storage.