BatchError

Enum BatchError 

pub enum BatchError {
    EmptyBatch,
    InvalidCommitTimestamp {
        read_ts: Timestamp,
        commit_ts: Timestamp,
    },
    CommitTsTooOld {
        key: Vec<u8>,
        commit_ts: Timestamp,
        latest_commit_ts: Timestamp,
    },
    NoReadGuards,
    DuplicateKeyInBatch {
        key: Vec<u8>,
    },
    KeyLocked {
        key: Vec<u8>,
        txn_id: TxnId,
    },
    GuardFailedNewerVersion {
        key: Vec<u8>,
        read_ts: Timestamp,
        actual_commit_ts: Timestamp,
    },
    GuardFailedVersionMismatch {
        key: Vec<u8>,
        expected: Option<Timestamp>,
        actual: Option<Timestamp>,
    },
    GuardFailedValueMismatch {
        key: Vec<u8>,
    },
    Backend(String),
}
Error during a direct or guarded batch.

Variants



EmptyBatch

The batch contained no write operations.



InvalidCommitTimestamp

The commit timestamp is less than or equal to a guard’s read timestamp.

Fields

read_ts: Timestamp

The read timestamp of the guard.

commit_ts: Timestamp

The invalid commit timestamp.



CommitTsTooOld

The commit timestamp is older than the latest committed version for a key.

Fields

key: Vec<u8>

The key that caused the error.

commit_ts: Timestamp

The requested commit timestamp.

latest_commit_ts: Timestamp

The latest committed version’s timestamp.



NoReadGuards

A guarded batch was submitted without any read guards.



DuplicateKeyInBatch

The batch contains multiple physical writes for the same key.

Fields

key: Vec<u8>

The duplicate key.



KeyLocked

A key in the batch is currently locked by an active intent.

Fields

key: Vec<u8>

The locked key.

txn_id: TxnId

The transaction ID holding the lock.



GuardFailedNewerVersion

A read guard failed because a newer version exists after the read_ts.

Fields

key: Vec<u8>

The key that failed the guard.

read_ts: Timestamp

The read timestamp of the guard.

actual_commit_ts: Timestamp

The timestamp of the newer version.



GuardFailedVersionMismatch

A read guard failed because the actual version did not match the expected version.

Fields

key: Vec<u8>

The key that failed the guard.

expected: Option<Timestamp>

The expected commit timestamp (or None if expected absent).

actual: Option<Timestamp>

The actual commit timestamp found (or None if actually absent).



GuardFailedValueMismatch

A read guard failed because the actual logical value did not match the expected value.

Fields

key: Vec<u8>

The key that failed the guard.



Backend(String)

An error returned by the backend storage.