pub enum CommitError {
IntentNotFound,
TxnIdMismatch,
StartTsMismatch,
InvalidCommitTimestamp {
start_ts: Timestamp,
commit_ts: Timestamp,
},
DuplicateCommitTimestamp {
commit_ts: Timestamp,
},
CommitTsTooOld {
commit_ts: Timestamp,
latest_commit_ts: Timestamp,
},
CommitTsTooEarly {
commit_ts: Timestamp,
min_commit_ts: Timestamp,
},
Backend(String),
}Expand description
Error during a single-key commit operation.
Variants
IntentNotFound
The intent to be committed was not found.
TxnIdMismatch
The transaction ID on the intent does not match the commit request.
StartTsMismatch
The start timestamp on the intent does not match the commit request.
InvalidCommitTimestamp
The commit timestamp is less than or equal to the start timestamp.
Fields
DuplicateCommitTimestamp
A committed version already exists exactly at this commit timestamp.
CommitTsTooOld
The commit timestamp is older than the latest committed version for a key.
Fields
CommitTsTooEarly
The commit timestamp is earlier than the intent’s required minimum commit timestamp.
Fields
Backend(String)
An error returned by the backend storage.