pub enum BatchError {
EmptyBatch,
InvalidCommitTimestamp {
read_ts: Timestamp,
commit_ts: Timestamp,
},
CommitTsTooOld {
key: Vec<u8>,
commit_ts: Timestamp,
latest_commit_ts: Timestamp,
},
NoReadGuards,
DuplicateKeyInBatch {
key: Vec<u8>,
},
KeyLocked {
key: Vec<u8>,
txn_id: TxnId,
},
GuardFailedNewerVersion {
key: Vec<u8>,
read_ts: Timestamp,
actual_commit_ts: Timestamp,
},
GuardFailedVersionMismatch {
key: Vec<u8>,
expected: Option<Timestamp>,
actual: Option<Timestamp>,
},
GuardFailedValueMismatch {
key: Vec<u8>,
},
Backend(String),
}Expand description
Error during a direct or guarded batch.
Variants
EmptyBatch
The batch contained no write operations.
InvalidCommitTimestamp
The commit timestamp is less than or equal to a guard’s read timestamp.
Fields
CommitTsTooOld
The commit timestamp is older than the latest committed version for a key.
Fields
NoReadGuards
A guarded batch was submitted without any read guards.
DuplicateKeyInBatch
The batch contains multiple physical writes for the same key.
KeyLocked
A key in the batch is currently locked by an active intent.
GuardFailedNewerVersion
A read guard failed because a newer version exists after the read_ts.
Fields
GuardFailedVersionMismatch
A read guard failed because the actual version did not match the expected version.
Fields
GuardFailedValueMismatch
A read guard failed because the actual logical value did not match the expected value.
Backend(String)
An error returned by the backend storage.